@@ -205,7 +205,7 @@ m68k_OutputExtensionWords(SAddressingMode* mode) {
 
         case AM_PCXDISP020: {
             if (mode->outer.displacement)
-                mode->outer.displacement = expr_PcRelative(mode->outer.displacement, 2);
+                mode->outer.displacement = expr_PcRelative(mode->outer.displacement, 0);
         }
         // fall through
         case AM_AXDISP020: {
@@ -267,7 +267,7 @@ m68k_OutputExtensionWords(SAddressingMode* mode) {
 
         case AM_PREINDPCXD020: {
             if (mode->inner.displacement)
-                mode->inner.displacement = expr_PcRelative(mode->inner.displacement, 2);
+                mode->inner.displacement = expr_PcRelative(mode->inner.displacement, 0);
         }
         // fall through
         case AM_PREINDAXD020: {
@@ -358,7 +358,7 @@ m68k_OutputExtensionWords(SAddressingMode* mode) {
 
         case AM_POSTINDPCXD020: {
             if (mode->inner.displacement)
-                mode->inner.displacement = expr_PcRelative(mode->inner.displacement, 2);
+                mode->inner.displacement = expr_PcRelative(mode->inner.displacement, 0);
         }
         // fall through
         case AM_POSTINDAXD020: {
@@ -731,12 +731,14 @@ m68k_ParseCommonCpuFpu(SInstruction* instruction, EToken token, bool allowFloat)
                 return true;
             }
         } else {
-            if ((instruction->allowedSourceModes & AM_EMPTY) == 0)
-                return true;
+            if ((instruction->allowedSourceModes & AM_EMPTY) == 0) {
+				err_Error(ERROR_OPERAND);
+				return true;
+			}
         }
     }
 
-    if (instruction->allowedDestModes != 0) {
+    if (instruction->allowedDestModes != 0 && instruction->allowedDestModes != AM_EMPTY) {
         if (lex_Context->token.id == ',') {
             parse_GetToken();
             if (!m68k_GetAddressingMode(&dest, allowFloat))
