@@ -241,7 +241,7 @@ getOuterMode(SAddressingMode* outMode) {
 
 static void
 optimizeFields(SModeRegisters* registers) {
-    if (registers->displacement != NULL && expr_IsConstant(registers->displacement) && registers->displacement->value.integer == 0) {
+    if (registers->baseRegister != REG_PC && registers->displacement != NULL && expr_IsConstant(registers->displacement) && registers->displacement->value.integer == 0) {
         expr_Free(registers->displacement);
         registers->displacement = NULL;
     }
@@ -594,7 +594,12 @@ m68k_GetAddressingMode(SAddressingMode* addrMode, bool allowFloat) {
     if (lex_Context->token.id == '(') {
         parse_GetToken();
 
+		bool hasDisplacement = addrMode->outer.displacement != NULL;
+
         if (getOuterMode(addrMode)) {
+			if (hasDisplacement && addrMode->outer.baseRegister != REG_NONE && addrMode->outer.displacementSize == SIZE_DEFAULT) {
+				addrMode->outer.displacementSize = SIZE_BYTE;
+			}
             return optimizeMode(addrMode);
         }
         return false;
