@@ -16,7 +16,9 @@
     along with ASMotor.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "options.h"
 #include "symbol.h"
+#include "xasm.h"
 
 #include "m68k_symbols.h"
 
@@ -34,9 +36,11 @@ createGroup(const char* name, EGroupType type, uint32_t flags) {
 
 void
 m68k_DefineSymbols(void) {
-    createGroup("CODE", GROUP_TEXT, 0);
-    createGroup("DATA", GROUP_TEXT, SYMF_DATA);
-    createGroup("BSS", GROUP_BSS, 0);
+	if (opt_Current->createGroups) {
+		createGroup("CODE", GROUP_TEXT, 0);
+		createGroup("DATA", GROUP_TEXT, SYMF_DATA);
+		createGroup("BSS", GROUP_BSS, 0);
+	}
 
 	string* regmask = str_Create("__USED_REGMASK");
     g_usedRegisters = sym_CreateEqu(regmask, 0);
@@ -45,22 +49,24 @@ m68k_DefineSymbols(void) {
 
 void
 m68k_DefineMachineGroups(EPlatform68k platform) {
-	switch (platform) {
-		case PLATFORM_AMIGA:
-			createGroup("CODE_C", GROUP_TEXT, SYMF_SHARED);
-			createGroup("DATA_C", GROUP_TEXT, SYMF_DATA | SYMF_SHARED);
-			createGroup("BSS_C", GROUP_BSS, SYMF_SHARED);
-			break;
-		case PLATFORM_A2650K:
-			createGroup("DATA_VA", GROUP_TEXT, SYMF_DATA);
-			createGroup("BSS_VA", GROUP_BSS, 0);
-			createGroup("DATA_VB", GROUP_TEXT, SYMF_DATA);
-			createGroup("BSS_VB", GROUP_BSS, 0);
-			createGroup("DATA_D", GROUP_TEXT, SYMF_DATA);
-			createGroup("BSS_D", GROUP_BSS, 0);
-			break;
-		default:
-			break;
+	if (opt_Current->createGroups) {
+		switch (platform) {
+			case PLATFORM_AMIGA:
+				createGroup("CODE_C", GROUP_TEXT, SYMF_SHARED);
+				createGroup("DATA_C", GROUP_TEXT, SYMF_DATA | SYMF_SHARED);
+				createGroup("BSS_C", GROUP_BSS, SYMF_SHARED);
+				break;
+			case PLATFORM_A2560K:
+				createGroup("DATA_VA", GROUP_TEXT, SYMF_DATA);
+				createGroup("BSS_VA", GROUP_BSS, 0);
+				createGroup("DATA_VB", GROUP_TEXT, SYMF_DATA);
+				createGroup("BSS_VB", GROUP_BSS, 0);
+				createGroup("DATA_D", GROUP_TEXT, SYMF_DATA);
+				createGroup("BSS_D", GROUP_BSS, 0);
+				break;
+			default:
+				break;
+		}
 	}
 }
 
