@@ -185,7 +185,7 @@ COMBINE_BITWISE(Asl, <<, T_OP_BITWISE_ASL)
 
 COMBINE_ARITHMETIC(Add, +, T_OP_ADD)
 
-COMBINE_ARITHMETIC(Mul, *, T_OP_ADD)
+COMBINE_ARITHMETIC(Mul, *, T_OP_MULTIPLY)
 
 COMBINE_ARITHMETIC(BooleanOr, ||, T_OP_BOOLEAN_OR)
 
