@@ -17,26 +17,31 @@
 */
 
 #include <assert.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
 // From util
 #include "file.h"
+#include "lists.h"
+#include "map.h"
 #include "mem.h"
+#include "str.h"
 #include "strbuf.h"
 #include "strcoll.h"
+#include "util.h"
+#include "vec.h"
 
 // From xasm
-#include "xasm.h"
 #include "crc32.h"
 #include "dependency.h"
 #include "errors.h"
 #include "includes.h"
 #include "lexer_buffer.h"
 #include "lexer_context.h"
+#include "options.h"
 #include "symbol.h"
-#include "tokens.h"
 
 
 /* Internal variables */
@@ -178,7 +183,7 @@ lexctx_ShiftMacroArgs(int32_t count) {
 }
 
 extern string*
-lexctx_Dump(void) {
+lexctx_GetFilenameBreadcrumb(void) {
 	string_buffer* buf = strbuf_Create();
 
 	if (lex_Context == NULL) {
@@ -205,6 +210,21 @@ lexctx_Dump(void) {
 	return str;
 }
 
+
+extern uint32_t
+lexctx_GetMainFileLineNumber(void) {
+	if (lex_Context == NULL)
+		return 0;
+
+	SLexerContext* stack = lex_Context;
+	while (list_GetNext(stack)) {
+		stack = list_GetNext(stack);
+	}
+
+	return stack->lineNumber;
+}
+
+
 static void
 copyToken(SLexerToken* dest, const SLexerToken* src) {
 	dest->id = src->id;
