@@ -32,12 +32,14 @@
 #include "lexer_context.h"
 #include "options.h"
 #include "parse.h"
+#include "parse_expression.h"
 #include "parse_string.h"
 #include "section.h"
 #include "symbol.h"
 #include "tokens.h"
 #include "xasm.h"
 
+
 static int32_t
 stringCompare(string* s) {
     int32_t r = 0;
@@ -365,6 +367,28 @@ handleDefFunction(void) {
     return NULL;
 }
 
+SExpression*
+handleRandFunction(void) {
+    parse_GetToken();
+
+    if (parse_ExpectChar('(')) {
+		int32_t lower_bound = parse_ConstantExpression();
+		if (parse_ExpectChar(',')) {
+			int32_t upper_bound = parse_ConstantExpression();
+			if (parse_ExpectChar(')')) {
+				// Xorshift algorithm
+				s_randseed ^= (s_randseed << 13);
+				s_randseed ^= (s_randseed >> 17);
+				s_randseed ^= (s_randseed << 5);
+
+				return expr_Const(s_randseed % (1 + upper_bound - lower_bound) + lower_bound);
+			}
+		}
+	}
+
+	return NULL;
+}
+
 SExpression*
 handleBankFunction(void) {
     assert(xasm_Configuration->supportBanks);
@@ -409,6 +433,8 @@ expressionPriority7(size_t maxStringConstLength) {
             return handleDefFunction();
         case T_FUNC_BANK:
             return handleBankFunction();
+        case T_FUNC_RAND:
+            return handleRandFunction();
         default: {
             SExpression* expr = xasm_Configuration->parseFunction();
             if (expr != NULL)
