@@ -19,6 +19,13 @@
 #ifndef XASM_MOTOR_PARSE_SYMBOL_H_INCLUDED_
 #define XASM_MOTOR_PARSE_SYMBOL_H_INCLUDED_
 
+#include <stdbool.h>
+#include <stdint.h>
+
+#include "symbol.h"
+
+extern SSymbol* g_rsSymbol;
+
 extern int32_t
 parse_IncrementRs(int32_t size);
 
