@@ -92,12 +92,17 @@ typedef struct Symbol {
 extern SSymbol*
 sym_CurrentScope;
 
+extern uint32_t s_randseed;
+
 extern bool
 sym_Init(void);
 
 extern void
 sym_Exit(void);
 
+extern bool
+sym_ReadMachineDefinitionFile(const char* name);
+
 extern SSymbol*
 sym_CreateLabel(string* name);
 
