@@ -61,7 +61,10 @@ typedef enum {
 
 	T_FUNC_BANK,
 	T_FUNC_ALIGN,
+	T_FUNC_PAGE,
 	T_FUNC_ROOT,
+	
+	T_FUNC_RAND,
 
 	T_OP_FDIV,
 	T_OP_FMUL,
@@ -114,6 +117,8 @@ typedef enum {
 
 	T_DIRECTIVE_FAIL,
 	T_DIRECTIVE_WARN,
+	T_DIRECTIVE_ASSERTF,
+	T_DIRECTIVE_ASSERTW,
 
 	T_DIRECTIVE_INCLUDE,
 	T_DIRECTIVE_INCBIN,
@@ -164,7 +169,9 @@ typedef enum {
 	T_DIRECTIVE_PUSHS,
 	T_DIRECTIVE_POPS,
 
-	T_DIRECTIVE_LAST = T_DIRECTIVE_POPS,
+	T_DIRECTIVE_RANDSEED,
+
+	T_DIRECTIVE_LAST = T_DIRECTIVE_RANDSEED,
 
 	// Dummy tokens not produced by the lexer follow:
 	
