@@ -29,9 +29,11 @@ createGroup(const char* name, EGroupType type) {
 
 void
 schip_DefineSymbols(void) {
-    createGroup("CODE", GROUP_TEXT);
-	createGroup("DATA", GROUP_TEXT);
-	createGroup("BSS", GROUP_BSS);
+	if (opt_Current->createGroups) {
+		createGroup("CODE", GROUP_TEXT);
+		createGroup("DATA", GROUP_TEXT);
+		createGroup("BSS", GROUP_BSS);
+	}
 }
 
 bool
