@@ -20,7 +20,7 @@
  * xLink - OBJECT.C
  *
  *	char	ID[3]="XOB";
- *  uint8_t version = 5;
+ *  uint8_t version = 6;
  *	[>=v1] char	MinimumWordSize ; Used for address calculations.
  *							; 1 - A CPU address points to a byte in memory
  *							; 2 - A CPU address points to a 16 bit word in memory (CPU address 0x1000 is the 0x2000th byte)
@@ -46,6 +46,7 @@
  *			[>=v1] int32_t BasePC	; -1 = not fixed
  *			[>=v3] int32_t ByteAlign ; -1 = not aligned
  *			[>=v4] uint8_t Rooted ; != 0 is rooted
+ *			[>=v6] int32_t Page ; -1 = not paged
  *			uint32_t	NumberOfSymbols
  *			REPT	NumberOfSymbols
  *					ASCIIZ	Name
@@ -84,7 +85,9 @@
  *	ENDR
  */
 
+#include <assert.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -284,6 +287,12 @@ readSection(FILE* fileHandle, SSection* section, Groups* groups, int version, ui
     else
         section->root = false;
 
+    if (version >= 6)
+        section->page = fgetll(fileHandle);
+    else
+        section->page = -1;
+
+
     section->totalSymbols = readSymbols(fileHandle, &section->symbols, version, fileInfoIndex);
 
     if (version >= 2) {
@@ -385,10 +394,10 @@ readXOBn(FILE* fileHandle, int32_t version, uint32_t fileId) {
 }
 
 static bool
-readChunk(FILE* fileHandle);
+readChunk(FILE* fileHandle, const char* filename);
 
 static void
-readXLB0(FILE* fileHandle) {
+readXLB0(FILE* fileHandle, const char* filename) {
     uint32_t count = fgetll(fileHandle);
 
     while (count--) {
@@ -396,12 +405,12 @@ readXLB0(FILE* fileHandle) {
         }  // Skip name
         fgetll(fileHandle);           // Skip length
 
-        readChunk(fileHandle);
+        readChunk(fileHandle, filename);
     }
 }
 
 static bool
-readChunk(FILE* fileHandle) {
+readChunk(FILE* fileHandle, const char* filename) {
     uint32_t id = fgetll(fileHandle);
 
     switch (id) {
@@ -435,13 +444,18 @@ readChunk(FILE* fileHandle) {
             return true;
         }
 
+        case MAKE_ID('X', 'O', 'B', 6): {
+            readXOBn(fileHandle, 6, g_fileId++);
+            return true;
+        }
+
         case MAKE_ID('X', 'L', 'B', 0): {
-            readXLB0(fileHandle);
+            readXLB0(fileHandle, filename);
             return true;
         }
 
         case MAKE_ID(0x7F, 'E', 'L', 'F'): {
-            elf_Read(fileHandle, g_fileId++);
+            elf_Read(fileHandle, filename, g_fileId++);
             return false;
         }
 
@@ -451,20 +465,36 @@ readChunk(FILE* fileHandle) {
     }
 }
 
+extern SFileInfo*
+obj_AllocateFileInfo(uint32_t count) {
+	uint32_t index = g_fileInfoCount;
+
+	g_fileInfoCount += count;
+	g_fileInfo = mem_Realloc(g_fileInfo, sizeof(SFileInfo) * g_fileInfoCount);
+
+	for (uint32_t i = 0; i < count; ++i) {
+		g_fileInfo[index + i].fileName = NULL;
+		g_fileInfo[index + i].crc32 = 0;
+		g_fileInfo[index + i].index = index + i;
+	}
+
+	return &g_fileInfo[index];
+}
+
 void
-obj_Read(char* fileName) {
+obj_Read(char* filename) {
     FILE* fileHandle;
 
-    if ((fileHandle = fopen(fileName, "rb")) != NULL) {
+    if ((fileHandle = fopen(filename, "rb")) != NULL) {
         size_t size = fsize(fileHandle);
 
         while ((size_t) ftell(fileHandle) < size
-             && readChunk(fileHandle))
+             && readChunk(fileHandle, filename))
         {}
 
         fclose(fileHandle);
     } else {
-        error("File \"%s\" not found", fileName);
+        error("File \"%s\" not found", filename);
     }
 }
 
